@@ -124,9 +124,6 @@ gPodderSettings = {
     # Tray icon and notification settings
     'display_tray_icon': (bool, False,
       ("Whether or not gPodder should display an icon in the system tray.")),
-    'minimize_to_tray': (bool, False,
-      ("If 'display_tray_icon' is enabled, when gPodder is minimized it will "
-        "not be visible in the window list.")),  
     'start_iconified': (bool, False,
       ("When gPodder starts, send it to the tray immediately.")),
     'enable_notifications': (bool, True,
@@ -159,8 +156,6 @@ gPodderSettings = {
       ("Whether or not the player requires Windows-style paths in the playlist.")),
 
     # Special settings (not in preferences)
-    'on_quit_systray': (bool, False,
-      ("When the 'X' button is clicked do not quit, send gPodder to the tray.")),
     'max_episodes_per_feed': (int, 200,
       ("The maximum number of episodes that gPodder will display in the episode "
         "list. Note: Set this to a lower value on slower hardware to speed up "
